@@ -13,14 +13,6 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Mac::Pasteboard ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-
 {
     my @const = qw{
         defaultFlavor
@@ -45,13 +37,16 @@ our @ISA = qw(Exporter);
 	const => \@const,
     );
 
-    our @EXPORT = @funcs;
+    # We have a functional interface, and at this point no longer
+    # exporting it by default would be a change in the public
+    # interface. So we disable Perl::Critic.
+    our @EXPORT = @funcs;	## no critic (ProhibitAutomaticExportation)
 }
 
-our $VERSION = '0.000_04';
+our $VERSION = '0.002_90';
 our $XS_VERSION = $VERSION;
 our $ALPHA_VERSION = $VERSION;
-$VERSION = eval $VERSION;  # see L<perlmodstyle>
+$VERSION =~ s/_//g;
 
 require XSLoader;
 XSLoader::load('Mac::Pasteboard', $XS_VERSION);
@@ -64,14 +59,16 @@ BEGIN {
     } or do {
 	*dualvar = sub {$_[0]};
     };
-    eval {require Mac::Errors};
-}
 
-# Preloaded methods go here.
+    eval {	## no critic (RequireCheckingReturnValueOfEval)
+	require Mac::Errors;	# Optional
+	1;
+    };
+}
 
 my %attr = (
     fatal => 1,		# read/write
-    id => sub {
+    id => sub {		# read/write. This is the mutator.
 	if (defined $_[2]) {
 	    if ($_[2] eq 'undef') {
 		$_[2] = undef;
@@ -84,7 +81,7 @@ my %attr = (
     },
     missing_ok => 1,	# read/write
     name => 0,		# read only
-    status => sub {
+    status => sub {	# read/write. This is the mutator.
 	$_[2] =~ m/^[+\-]?\d+$/
 	    or croak "Status value must be an integer";
 	_error ($_[2]);
@@ -96,9 +93,9 @@ my %static = (
 );
 
 sub new {
-    my $class = ref $_[0] || $_[0];
-    shift;
-    my $name = @_ ? shift : kPasteboardClipboard ();
+    my ($class, $name) = @_;
+    ref $class and $class = ref $class;
+    defined $name or $name = kPasteboardClipboard();
     $ENV{DEVELOPER_DEBUG}
 	and warn __PACKAGE__, "->new() creating $name";
     my $self = bless {
@@ -106,18 +103,18 @@ sub new {
 	id => undef,
 	missing_ok => 0,
 	name => $name,
-    };
+    }, $class;
     my ($status, $pbref, $created_name) = xs_pbl_create ($self->{name});
-    __PACKAGE__->_check ($status) and return undef;
+    __PACKAGE__->_check ($status) and return;
     $created_name and $self->{name} = $created_name;
     $self->{pbref} = $pbref;
     $self->{status} = $static{status};
-    $self;
+    return $self;
 }
 
 sub clear {
     my ($self) = @_;
-    $self->_check (xs_pbl_clear ($self->{pbref}));
+    return $self->_check (xs_pbl_clear ($self->{pbref}));
 }
 
 sub clone {
@@ -126,15 +123,15 @@ sub clone {
     if (defined (my $pbref = $self->{pbref})) {
 	xs_pbl_retain ($pbref);
     }
-    bless $clone, ref $self;
+    return bless $clone, ref $self;
 }
 
 sub copy {
     my ($self, $data, $flavor, $flags) = @_;
-    defined $flavor && $flavor ne ''
+    (defined $flavor && $flavor ne '')
 	or $flavor = defaultFlavor ();
     defined $flags or $flags = kPasteboardFlavorNoFlags ();
-    $self->_check (
+    return $self->_check (
 	xs_pbl_copy (
 	    $self->{pbref}, $data,
 	    (defined $self->{id} ? $self->{id} : 1), $flavor, $flags)
@@ -146,7 +143,7 @@ sub flavors {
     my ($status, @data) = xs_pbl_all (
 	$self->{pbref}, $self->{id}, 0, $conforms_to);
     $self->_check ($status) and return;
-    wantarray ? @data : \@data;
+    return wantarray ? @data : \@data;
 }
 
 {
@@ -168,31 +165,31 @@ sub flavors {
 	    push @rslt, $name;
 	}
 	@rslt or push @rslt, 'kPasteboardFlavorNoFlags';
-	wantarray ? @rslt : join ', ', @rslt;
+	return wantarray ? @rslt : join ', ', @rslt;
     }
 }
 
 sub flavor_tags {
     my $flavor = pop;
     my $hash = xs_pbl_uti_tags ($flavor);
-    wantarray ? %$hash : $hash;
+    return wantarray ? %$hash : $hash;
 }
 
 sub get {
     my ($self, $name) = @_;
     exists $attr{$name}
 	or croak "No such attribute as '$name'";
-    ref $self ? $self->{$name} : $static{$name};
+    return ref $self ? $self->{$name} : $static{$name};
 }
 
 sub paste {
     my ($self, $flavor) = @_;
-    defined $flavor && $flavor ne ''
+    (defined $flavor && $flavor ne '')
 	or $flavor = defaultFlavor ();
     my ($status, $data, $flags) = xs_pbl_paste (
 	$self->{pbref}, $self->{id}, $flavor);
     $self->_check ($status);
-    wantarray ? ($data, $flags) : $data;
+    return wantarray ? ($data, $flags) : $data;
 }
 
 sub paste_all {
@@ -200,51 +197,51 @@ sub paste_all {
     my ($status, @data) = xs_pbl_all (
 	$self->{pbref}, $self->{id}, 1, $conforms_to);
     $self->_check ($status) and return;
-    wantarray ? @data : \@data;
+    return wantarray ? @data : \@data;
 }
 
-sub pbcopy (;$$$) {
+sub pbcopy (;$$$) {		## no critic (ProhibitSubroutinePrototypes)
     unshift @_, kPasteboardClipboard ();
     goto &_pbcopy;
 }
 
-sub pbcopy_find (;$$$) {
+sub pbcopy_find (;$$$) {	## no critic (ProhibitSubroutinePrototypes)
     unshift @_, kPasteboardFind ();
     goto &_pbcopy;
 }
 
-sub pbpaste (;$) {
+sub pbpaste (;$) {		## no critic (ProhibitSubroutinePrototypes)
     unshift @_, kPasteboardClipboard ();
     goto &_pbpaste;
 }
 
-sub pbpaste_find (;$) {
+sub pbpaste_find (;$) {		## no critic (ProhibitSubroutinePrototypes)
     unshift @_, kPasteboardFind ();
     goto &_pbpaste;
 }
 
 sub set {
-    my $self = shift;
+    my ($self, @args) = @_;
     my $hash = ref $self ? $self : \%static;
-    while (@_) {
-	my $name = shift;
+    while (@args) {
+	my $name = shift @args;
 	exists $attr{$name}
 	    or croak "No such attribute as '$name'";
 	$attr{$name}
 	    or croak "Attribute '$name' is read-only";
 	my $ref = ref $attr{$name};
 	if ($ref eq 'CODE') {
-	    $hash->{$name} = $attr{$name}->($self, $name, shift);
+	    $hash->{$name} = $attr{$name}->($self, $name, shift @args);
 	} else {
-	    $hash->{$name} = shift;
+	    $hash->{$name} = shift @args;
 	}
     }
-    $self;
+    return $self;
 }
 
 sub synch {
     my ($self) = @_;
-    xs_pbl_synch ($self->{pbref});
+    return xs_pbl_synch ($self->{pbref});
 }
 
 {
@@ -259,7 +256,7 @@ sub synch {
 	    $flag & $flags{$name} or next;
 	    push @rslt, $name;
 	}
-	wantarray ? @rslt : join ', ', @rslt;
+	return wantarray ? @rslt : join ', ', @rslt;
     }
 }
 
@@ -304,18 +301,18 @@ sub synch {
     sub _error {
 	my $val = pop;
 	if (!$val) {
-	    dualvar (0, '');
+	    return dualvar (0, '');
 	} elsif (my $err = $Mac::Errors::MacErrors{$val}) {
-	    dualvar ($val,
+	    return dualvar ($val,
 		sprintf ('Mac OS error %d (%s): %s',
 		    $err->number, $err->symbol, $err->description));
 	} elsif (exists $errtxt{$val}) {
-	    dualvar ($val,
+	    return dualvar ($val,
 		sprintf ('%s error %d (%s): %s',
 		    $errtxt{$val}{type} || 'Pasteboard', $val,
 		    $errtxt{$val}{sym}, $errtxt{$val}{desc}));
 	} else {
-	    dualvar ($val, "Unknown error ($val)");
+	    return dualvar ($val, "Unknown error ($val)");
 	}
     }
 
@@ -324,11 +321,11 @@ sub synch {
 	my $hash = ref $self ? $self : \%static;
 	$hash->{status} = my $dual = _error ($error);
 	if ($error == -25133 && $hash->{missing_ok}) {
-	    $dual;
+	    return $dual;
 	} elsif ($error && $hash->{fatal}) {
 	    croak $dual;
 	} else {
-	    $dual;
+	    return $dual;
 	}
     }
 }
@@ -338,22 +335,22 @@ sub synch {
     my %cache;	# So we don't have to keep instantiating pasteboards.
 
     sub _pbcopy {
-	my $name = shift;
+	my ($name, @args) = @_;
 	my $pb = $cache{$name} ||= __PACKAGE__->new ($name);
-	@_ or push @_, $_;
+	@args or push @args, $_;
 	$pb->clear ();
 	$pb->set (id => undef);	# should be undef anyway, but ...
-	$pb->copy (@_);
+	return $pb->copy (@args);
     }
 
     sub _pbpaste {
-	my $name = shift;
+	my ($name, @args) = @_;
 	my $pb = $cache{$name} ||= __PACKAGE__->new ($name);
 	$pb->set (
-	    id => undef,		# should be undef anyway, but ...
+	    id => undef,	# should be undef anyway, but ...
 	    missing_ok => 1,	# no exception for missing data ...
 	);
-	$pb->paste (@_);
+	return $pb->paste (@args);
     }
 
 }
@@ -361,6 +358,7 @@ sub synch {
 sub DESTROY {
     my ($self) = @_;
     $self->{pbref} and xs_pbl_release ($self->{pbref});
+    return;
 }
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
@@ -398,14 +396,6 @@ ssh connection, and probably from a cron job as well, depending on your
 version of Mac OS X. This restriction appears to apply not only to the
 system clipboard but to privately-created pasteboards.
 
-This release is for evaluation only. It is early-alpha code at this
-point. The author makes no commitment whatsoever concerning the
-stability of the interface. Have fun.
-
-Version 0.000_04 recognizes the restrictions in use, and allows for them
-in testing. Static attributes 'fatal' and 'status' support this. It also
-eliminates a free() error when these restrictions are encountered.
-
 =head1 DESCRIPTION
 
 This XS module accesses Mac OS X pasteboards, which can be thought of as
@@ -426,7 +416,7 @@ describes the bells and whistles associated with a Mac OS X pasteboard.
 
 A Mac OS X pasteboard contains zero or more data items, each of which is
 capable of holding one or more flavors of data. The system defines a
-couple, including the system clipboard, named
+couple pasteboards, including the system clipboard, named
 'com.apple.pasteboard.clipboard'. The system clipboard is the default
 taken if new() is called without arguments.
 
@@ -444,8 +434,8 @@ used, but you probably want to stick to the system-declared flavors if
 it is important to you that other software understand your data. The
 L</SEE ALSO> section contains a link to a reference for Uniform Type
 Identifiers which includes a description of all the system-declared
-UTIs. The desired flavor can be passed to any method (or subroutine)
-that places data on or retrieves data from the pasteboard, but defaults
+UTIs. All methods (or subroutines) that place data on or retrieve data
+from a pasteboard take the flavor as an argument. This argument defaults
 to 'com.apple.traditional-mac-plain-text'.
 
 Data may be placed on a pasteboard only by the owner of that pasteboard.
@@ -489,10 +479,9 @@ Passing undef to new() is B<not> equivalent to calling it with no
 arguments at all, since undef is the encoding for
 L</kPasteboardUniqueName>.
 
-Note that an error in creating a new
-pasteboard B<will> cause an exception, since the L<fatal|/fatal
-(boolean)> attribute defaults to 1. If you want to get a status back,
-you will need to call
+Note that an error in creating a new pasteboard B<will> cause an
+exception, since the L<fatal|/fatal (boolean)> attribute defaults to 1.
+If you want to get a status back, you will need to call
 
  Mac::Pasteboard->set (fatal => 0);
 
@@ -525,7 +514,7 @@ of other flavors remain on the pasteboard.
 
 If the L<id|/id (integer)> attribute is undef, the data are placed in
 the item whose id is 1. Otherwise, the data are placed in the item with
-the given id.  It is an error to attempt to place a given flavor on a
+the given id.  It is an error to attempt to place a given flavor in a
 given item more than once.
 
 =head2 @names = $pb->flavor_flag_names ($flags)
@@ -579,7 +568,8 @@ This method returns the value of the given L<attribute|/ATTRIBUTES>. An
 exception is thrown if the attribute does not exist.
 
 This method can also be called statically (that is, as
-Mac::Pasteboard->get ($name)).
+Mac::Pasteboard->get ($name)), in which case it returns the static value
+of the attribute, if any.
 
 =head2 ($data, $flags) = $pb->paste ($flavor)
 
@@ -767,6 +757,17 @@ the system pasteboard if no name was passed in. Under Tiger (Mac OS
 created. If this name cannot be retrieved you get the same result as
 under Panther.
 
+This name may not be the name you used to create the
+pasteboard, even if you used one of the built-in names. But unless you
+created the pasteboard using name kPasteboardUniqueName, the name will
+be equivalent. That is,
+
+ my $pb1 = Mac::Pasteboard->new();
+ my $pb2 = Mac::Pasteboard->new(
+     $pb1->get('name'));
+
+gives two handles to the same clipboard.
+
 =head2 status (dualvar)
 
 This attribute contains the status of the last operation. You can set
@@ -779,8 +780,10 @@ operate on a pasteboard. Currently, this means the last call to new().
 
 The pbcopy(), pbcopy_find(), pbpaste(), and pbpaste_find() subroutines
 are exported by default. In addition, tag ':all' exports everything, and
-tag ':const' exports constants. Constants are also accessible by
-&Mac::Pasteboard::constant_name. The following constants are defined:
+tag ':const' exports all constants except those which must be exported
+explicitly (currently only coreFoundationUnknownErr). Constants are also
+accessible by &Mac::Pasteboard::constant_name. The following constants
+are defined:
 
 =head2 Error codes
 
@@ -793,16 +796,17 @@ number of the error, which is -25133.
 =head3 duplicatePasteboardFlavorErr
 
 This constant represents the error number returned when an attempt is
-made to place on a pasteboard item a flavor that is already there.  It
+made to place in a pasteboard item a flavor that is already there.  It
 is not a dualvar -- it just represents the number of the error, which is
 -25134.
 
 =head3 badPasteboardIndexErr
 
 This constant represents the error number returned when the code indexes
-off the end of the pasteboard. As such, it represents a bug in this
-module, and should be reported as such. It is not a dualvar -- it just
-represents the number of the error, which is -25131.
+off the end of the pasteboard. If you get it in use, it probably
+represents a bug in this module, and should be reported as such. It is
+not a dualvar -- it just represents the number of the error, which is
+-25131.
 
 =head3 badPasteboardItemErr
 
@@ -875,8 +879,8 @@ available to the process that placed it on the pasteboard.
 
 Oddly enough, the 'pbpaste' executable seems to be able to find such
 data. But the Pasteboard Peeker demo application can not, so I am pretty
-sure this is working OK. Unfortunately I was unable to find the source
-for pbpaste online, so I am unable to verify what's going on.
+sure this module is working OK. Unfortunately I was unable to find the
+source for pbpaste online, so I am unable to verify what's going on.
 
 =head3 kPasteboardFlavorSenderTranslated
 
@@ -941,8 +945,10 @@ the author.
 
 The B<Clipboard> module by Ryan King will access text on the clipboard
 under most operating systems. Under Mac OS X, it shells out to the
-I<pbpaste> and I<pbcopy> executables. You can also shell out to these
-yourself if your script requires $^O eq 'darwin'.
+I<pbpaste> and I<pbcopy> executables.
+
+The I<pbpaste> and I<pbcopy> executables themselves are available, and
+described by their respective man pages.
 
 The I<Pasteboard Manager Reference> is available online at
 L<http://developer.apple.com/documentation/Carbon/Reference/Pasteboard_Reference/Reference/reference.html>.
@@ -958,10 +964,16 @@ Thomas R. Wyant, III, F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Thomas R. Wyant, III. All rights reserved.
+Copyright (C) 2008, 2011 by Thomas R. Wyant, III
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl 5.10.0. For more details, see the full text
+of the licenses in the directory LICENSES.
+
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =cut
+
+# ex: set textwidth=72 :
